construct_analysis: Internal Methods for Constructing IMR Analyses

Description Usage Arguments Details Value

View source: R/IMR-analysis_constructors.R

Description

An internal method used in the IMR for construction of the model analysis.

Usage

1
2
3
4
5
## Default S3 method:
construct_analysis(mc, data, ...)

## S3 method for class 'BS'
construct_analysis(mc, data, norder, knots, L, ...)

Arguments

mc

the classes of the fitted models to be analyzed via the constructed analysis funciton.

data

data from the first fitted model.

...

additional arguments.

Details

construct_analysis is a generic function. The methods should correspond to the inputted method in IMR.

Value

An analysis constructor must return the following in a list

analysis

a function with exactly one input, data, which has the same format as the inputted data.

method

a method list with info used in the plot.IMR and print.IMR functions.


Laksafoss/ICPSurv documentation built on Feb. 26, 2020, 11:32 a.m.