Description Usage Arguments Value See Also Examples
View source: R/ICP-methodobj.R
Creates a method object within the ICP function.
1 2 3 4 | method_obj(model = "glm", method = "EnvirRel", ...)
## S3 method for class 'method_obj'
print(x, exclude = c("id", "tol", "call", "dist"), ...)
|
model |
the regression model used in |
method |
the testing metod used in |
... |
further arguments to be passed to the
If If |
x |
a |
exclude |
variables from the |
The method_obj function returns a list with all the input
parameters and their values. This list has class "method_obj",
method and model. If method is CR then the
output list also has class equal to solver. If, however, the
method is TimeVar then the output also has class
nonparamtest.
ICP, plausible_predictor_test,
fit_model or fit_nonparam_model for use of the
method object.
1 2 3 4 5 6 7 | # The standard method object is a gaussian glm with method EnvirIrrel
ICPSurv:::method_obj()
# A method object for Intersecting Confidence Region analysis of linear models
ICPSurv:::method_obj(model = "lm", method = "CR", solver = "QC", fullAnalysis = TRUE)
# Here 'fullAnalysis' has been set to TRUE which will ensure that QCLP method
# does not use rectangle approximations as a first step
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.