Description Usage Arguments Details Value
View source: R/IMR-analysis_constructors.R
An internal method used in the IMR for construction of the
model analysis.
1 2 3 4 5 | ## Default S3 method:
construct_analysis(mc, data, ...)
## S3 method for class 'BS'
construct_analysis(mc, data, norder, knots, L, ...)
|
mc |
the classes of the fitted models to be analyzed via the constructed analysis funciton. |
data |
data from the first fitted model. |
... |
additional arguments. |
construct_analysis is a generic function. The methods should
correspond to the inputted method in IMR.
An analysis constructor must return the following in a list
analysis |
a function with exactly one input, |
method |
a method list with info used in the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.